==> solid-5.5.0.zip: solid-5.5.0/src/solid/devices/backends/fakehw/fakeopticaldisc.h <==
/*
    Copyright 2006 Davide Bettio <davide.bettio@kdemail.net>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_FAKEHW_FAKEOPTICALDISC_H
#define SOLID_BACKENDS_FAKEHW_FAKEOPTICALDISC_H

#include "fakevolume.h"
#include <solid/devices/ifaces/opticaldisc.h>

namespace Solid
{
namespace Backends
{
namespace Fake
{
class FakeOpticalDisc : public FakeVolume, virtual public Solid::Ifaces::OpticalDisc
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::OpticalDisc)

public:
    explicit FakeOpticalDisc(FakeDevice *device);
    virtual ~FakeOpticalDisc();

public Q_SLOTS:
    virtual Solid::OpticalDisc::ContentTypes availableContent() const;
    virtual Solid::OpticalDisc::DiscType discType() const;
    virtual bool isAppendable() const;
    virtual bool isBlank() const;
    virtual bool isRewritable() const;
    virtual qulonglong capacity() const;
};
}
}
}

#endif // SOLID_BACKENDS_FAKEHW_FAKEOPTICALDISC_H

==> solid-5.42.0.zip: solid-5.42.0/src/solid/devices/backends/fakehw/fakeopticaldisc.h <==
/*
    Copyright 2006 Davide Bettio <davide.bettio@kdemail.net>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SOLID_BACKENDS_FAKEHW_FAKEOPTICALDISC_H
#define SOLID_BACKENDS_FAKEHW_FAKEOPTICALDISC_H

#include "fakevolume.h"
#include <solid/devices/ifaces/opticaldisc.h>

namespace Solid
{
namespace Backends
{
namespace Fake
{
class FakeOpticalDisc : public FakeVolume, virtual public Solid::Ifaces::OpticalDisc
{
    Q_OBJECT
    Q_INTERFACES(Solid::Ifaces::OpticalDisc)

public:
    explicit FakeOpticalDisc(FakeDevice *device);
    virtual ~FakeOpticalDisc();

public Q_SLOTS:
    Solid::OpticalDisc::ContentTypes availableContent() const Q_DECL_OVERRIDE;
    Solid::OpticalDisc::DiscType discType() const Q_DECL_OVERRIDE;
    bool isAppendable() const Q_DECL_OVERRIDE;
    bool isBlank() const Q_DECL_OVERRIDE;
    bool isRewritable() const Q_DECL_OVERRIDE;
    qulonglong capacity() const Q_DECL_OVERRIDE;
};
}
}
}

#endif // SOLID_BACKENDS_FAKEHW_FAKEOPTICALDISC_H
